Learn R Programming

webdeveloper (version 0.1.0)

castDateString: Format a date string as " from a SQL database to a format compatible with a HTML date input value.

Description

Format a date string as " from a SQL database to a format compatible with a HTML date input value.

Usage

castDateString(x)

Arguments

x

A string.

Value

A string, formatted YYYY-MM-DD.

Examples

Run this code
# NOT RUN {
castDateString(Sys.time())
# }

Run the code above in your browser using DataLab